Struct plotlib::page::Page
[−]
[src]
pub struct Page<'a> { /* fields omitted */ }A single page page laying out the views in a grid
Methods
impl<'a> Page<'a>[src]
fn single(view: &'a View) -> Self[src]
Creates a plot containing a single view
fn to_svg(&self) -> Document[src]
Render the plot to an svg document
fn to_text(&self) -> String[src]
Render the plot to an String
fn save<P>(&self, path: P) where
P: AsRef<Path>, [src]
P: AsRef<Path>,
Save the plot to a file.
The type of file will be based on the file extension.